@@ -11,17 +11,19 @@
 #' - `original_curves`: A numeric matrix of shape \eqn{N \times L \times M}
 #' storing a sample with the \eqn{N} \eqn{L}-dimensional original curves
 #' observed on grids of size \eqn{M}.
-#' - `aligned_curves`: A numeric matrix of shape \eqn{N \times L \times M}
-#' storing a sample with the \eqn{N} \eqn{L}-dimensional aligned curves observed
-#' on grids of size \eqn{M}.
+#' - `original_grids`: A numeric matrix of size \eqn{N \times M} storing the
+#' grids of size \eqn{M} on which original curves are evaluated;
+#' - `aligned_grids`: A numeric matrix of size \eqn{N \times M} storing the
+#' grids of size \eqn{M} on which original curves must be evaluated to be
+#' aligned;
 #' - `center_curves`: A numeric matrix of shape \eqn{K \times L \times M}
 #' storing the \eqn{K} centers which are \eqn{L}-dimensional curves observed on
 #' a grid of size \eqn{M};
+#' - `center_grids`: A numeric matrix of size \eqn{K \times M} storing the grids
+#' of size \eqn{M} on which center curves are evaluated;
 #' - `warpings`: A numeric matrix of shape \eqn{N \times M} storing the
 #' estimated warping functions for each of the \eqn{N} curves evaluated on the
 #' within-cluster common `grids` of size \eqn{M};
-#' - `grids`: A numeric matrix of size \eqn{K \times M} storing the
-#' within-cluster common grids of size \eqn{M} on which curves are evaluated;
 #' - `n_clusters`: An integer value storing the number of clusters;
 #' - `memberships`: An integer vector of length \eqn{N} storing the cluster ID
 #' which each curve belongs to;
@@ -29,6 +31,9 @@
 #' distance of each curve to the center of its cluster;
 #' - `silhouettes`: A numeric vector of length \eqn{N} storing the silhouette
 #' values of each observation;
+#' - `amplitude_variation`: A numeric value storing the fraction of total
+#' variation explained by amplitude variability.
+#' - `total_variation`: A numeric value storing the amount of total variation.
 #' - `n_iterations`: An integer value storing the number of iterations
 #' performed until convergence;
 #' - `call_name`: A string storing the name of the function that was used to
@@ -57,14 +62,16 @@ as_caps <- function(x) {
   if (!inherits(x, "list"))
     cli::cli_abort("The input argument {.arg x} should be a list.")
 
-  if (length(x) != 14)
-    cli::cli_abort("The input argument {.arg x} should be a list of length 14.")
-
-  expected_names <- c("original_curves", "aligned_curves", "center_curves",
-                      "warpings", "grids", "n_clusters", "memberships",
-                      "distances_to_center", "silhouettes",
+  expected_names <- c("original_curves", "original_grids", "aligned_grids",
+                      "center_curves", "center_grids", "n_clusters",
+                      "memberships", "distances_to_center", "silhouettes",
                       "amplitude_variation", "total_variation", "n_iterations",
                       "call_name", "call_args")
+
+  n <- length(expected_names)
+  if (length(x) != n)
+    cli::cli_abort("The input argument {.arg x} should be a list of length {n}.")
+
   if (any(names(x) != expected_names))
     cli::cli_abort("The input argument {.arg x} should be a list with components {expected_names}.")
 
